<?php
/*
Plugin Name: DashBar [k]
Plugin URI: http://wp-plugins.net/plugin/dashbar-k
Description: Displays a WordPress.com-like navigation bar above the public blog pages, but only for logged-in users <em>who have sufficient Role privileges</em>. Provides direct access to Dashboard, Write Post, Edit Posts (with dropdown menu to select post to edit), Awaiting Moderation, My Profile,  and other functions appropriate to the current blog page, without having to manually go into the admin area. Also says which user you are, and provides a quick logout button, just like top of real WP admin pages.  This is a kluge of <a href="http://z720.net/produits/wordpress/dashbar/" target="_blank">S. Erard's original DashBar 1.1</a>, to make it more user-role selective (esp. for blogs that require ALL users to login to post comments, but give them no other Role capabilities; such users don't get the DashBar now), and to be more consistent with WP's own admin interface.  Only tested in WP 2.0. Allegedly compatible with WP 1.5.
Version: 1.0
Author: Stanton McCandlish (nominally)
Author URI: http://www.McCandlishConsulting.com
*/

/* Installation: Put in wp-content/plugins and enable the plugin in WP. */

/*
This is entirely based on this original plugin:

# Plugin Name: DashBar
# Plugin URI: http://z720.net/produits/wordpress/dashbar
# Description: Display a WordPress.com-like navigation bar for logged users: direct acces to Dashboard, Write, Edit, Awaiting Moderation, Profile.
# Version: 1.1
# Author: Sebastien Erard
# Author URI: http://z720.net/

Any changes made by me are noted clearly with initialled comments below. -S.McC.
(like that.)  If Msr. Erard updates his original to address the needs I'm
addressing here, I'll happily remove my kluge from distribution.

Erard neglected to put license terms in his original release, so I don't feel I can add them to this variant either.  I'm presuming GPL, but perhaps he intended CC or something else.
*/

class DashBar {
	var $color = '#14568a';
	
	function DashBar() {
		$c = get_option('DashBar_bgcolor');
		if($c) {
			$this->color = $c;
		}
		add_action('init', array(&$this, 'init'));
		//add_filter('admin_head', array(&$this, 'admin_header'));
		//add_action('admin_menu', array(&$this, 'set_mgt')); 			
	}

  function init() {
		get_currentuserinfo();
		global $userdata, $user_login, $user_identity;
		if($user_login) {
		  if ( current_user_can('publish_posts') ) {
			add_filter('wp_footer', array(&$this, 'display_footer'));
			add_filter('wp_head', array(&$this, 'display_header'));
          } // Added this 'if' around the filters to keep DashBar from
		}   // appearing for anyone not privileged enough to at least
  }         // write posts.  Can be customized for any current_user_can. -S.McC.
// PS: Erard's code looks counter-intuitive at first; what happens is wp_head
// gets some new CSS for DashBar, and the wp_footer actually loads the code for
// DashBar way down at the bottom and out of the path of search engines, then
// uses the CSS to absolute-position it at top of page.  Nice.  -S.McC.

	
	function set_mgt() {
		add_submenu_page('plugins.php', __('DashBar Config'), __('DashBar Config'), 3, basename(__FILE__), array(&$this, 'management_page'));
	}  // Got rid of the French in there, since this copy of the script is
	   // otherwise English-localized.  Moot point anyway, since the actual
	   // submenu function, 'management_page()' does not exist (yet). -S.McC.

	function display_footer() {
		echo '<div id="DashBar">'
				.'<div id="quicklinks">'
				.'<ul>'
				.'<li><a href="'.get_option('siteurl').'/wp-admin/">'.__('Dashboard').'</a></li>'
				.'<li><a href="'.get_option('siteurl').'/wp-admin/post.php">'.__('Write Post').'</a></li>';
		rewind_posts();
		if(is_single()||is_page()) {
			the_post();
			global $id;
			echo '<li><a href="'.get_option('siteurl').'/wp-admin/post.php?action=edit&amp;post='.$id.'" title="'.get_the_title().'">'.__('Edit').'</a></li>';
		} elseif(!is_404()) {
			if(have_posts()){
				echo '<li><form action="'.get_option('siteurl').'/wp-admin/post.php" method="get"><input type="hidden" name="action" value="edit" /><select name="post">';
				while(have_posts()) {
					the_post();
					global $id;
					echo '<option value="'.$id.'">'.get_the_title('','',false).'</option>';
				}
				echo '</select><input type="submit" value="&raquo;" /></form></li>';
			}
		}
		global $wpdb;
		$awaiting_mod = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->comments WHERE comment_approved = '0'");
		if($awaiting_mod) {
			echo '<li><a href="'.get_option('siteurl').'/wp-admin/moderation.php">'.sprintf(__("Awaiting Moderation (%s)"), $awaiting_mod).'</a></li>';
		}
		global $user_identity;
		echo '</ul>'
				.'</div>'
				.'<div id="loginout">'
				.'Howdy, '
				.'<strong>'
				.$user_identity
				.'</strong>. [<a href="'.get_option('siteurl').'/wp-login.php?action=logout">'.__('Sign Out').'</a>, <a href="'.get_option('siteurl').'/wp-admin/profile.php">'.__('My Account').'</a>]</div>'
				.'</div>';
	} // Now matches the actual WP admin pages' text.  -S.McC.

		
	function display_header() {
?>
<style type="text/css">
#DashBar {
	position: absolute;
	top: 0;
	left: 0;
	background: <?php echo $this->color; ?>;
	width: 100%;
	height: 30px;
	font-family: "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana;
	font-size: 12px;
}

#DashBar #quicklinks ul {
	list-style: none;
	margin: 0;
	padding: 0;
}

#DashBar #quicklinks li {
	float: left;
}

#DashBar #quicklinks a,
#DashBar #quicklinks form {
	display: block;
	padding: .5em 1em;
	color: #c3def1;
	text-decoration: none;
	font-weight: normal;
}
#DashBar #quicklinks select {width:200px;}
#DashBar #quicklinks a:hover {
	background: #6da6d1;
	color: black;
}

#DashBar #loginout {
	float:right;
	margin: 0 1em 0 0;
	padding: 7px 0 0 0;
	color: #c3def1;
}

#DashBar #loginout strong {
	color: #c3def1;
}

#DashBar #loginout a,
#DashBar #loginout a:hover {
	color: white;
}

body {
	padding-top: 30px;
}
</style>
<?php		
	}
	
}

$the_dashbar_variable = new DashBar();


?>